@@ -32,7 +32,7 @@ class TempestException(Exception):
         except Exception:
             # at least get the core message out if something happened
             self._error_string = self.message
-        if len(args) > 0:
+        if args:
             # If there is a non-kwarg parameter, assume it's the error
             # message or reason description and tack it on to the end
             # of the exception message
@@ -44,6 +44,9 @@ class TempestException(Exception):
     def __str__(self):
         return self._error_string
 
+    def __repr__(self):
+        return self._error_string
+
 
 class RestClientException(TempestException,
                           testtools.TestCase.failureException):
@@ -71,52 +74,73 @@ class InvalidHttpSuccessCode(OtherRestClientException):
     message = "The success code is different than the expected one"
 
 
-class NotFound(ClientRestClientException):
-    message = "Object not found"
+class BadRequest(ClientRestClientException):
+    status_code = 400
+    message = "Bad request"
 
 
 class Unauthorized(ClientRestClientException):
+    status_code = 401
     message = 'Unauthorized'
 
 
 class Forbidden(ClientRestClientException):
+    status_code = 403
     message = "Forbidden"
 
 
-class TimeoutException(OtherRestClientException):
-    message = "Request timed out"
+class NotFound(ClientRestClientException):
+    status_code = 404
+    message = "Object not found"
 
 
-class BadRequest(ClientRestClientException):
-    message = "Bad request"
+class Conflict(ClientRestClientException):
+    status_code = 409
+    message = "Conflict with state of target resource"
 
 
-class UnprocessableEntity(ClientRestClientException):
-    message = "Unprocessable entity"
+class Gone(ClientRestClientException):
+    status_code = 410
+    message = "The requested resource is no longer available"
+
+
+class PreconditionFailed(ClientRestClientException):
+    status_code = 412
+    message = "Precondition Failed"
 
 
 class RateLimitExceeded(ClientRestClientException):
+    status_code = 413
     message = "Rate limit exceeded"
 
 
 class OverLimit(ClientRestClientException):
+    status_code = 413
     message = "Request entity is too large"
 
 
+class InvalidContentType(ClientRestClientException):
+    status_code = 415
+    message = "Invalid content type provided"
+
+
+class UnprocessableEntity(ClientRestClientException):
+    status_code = 422
+    message = "Unprocessable entity"
+
+
 class ServerFault(ServerRestClientException):
+    status_code = 500
     message = "Got server fault"
 
 
 class NotImplemented(ServerRestClientException):
+    status_code = 501
     message = "Got NotImplemented error"
 
 
-class Conflict(ClientRestClientException):
-    message = "An object with that identifier already exists"
-
-
-class Gone(ClientRestClientException):
-    message = "The requested resource is no longer available"
+class TimeoutException(OtherRestClientException):
+    message = "Request timed out"
 
 
 class ResponseWithNonEmptyBody(OtherRestClientException):
@@ -137,10 +161,6 @@ class InvalidHTTPResponseHeader(OtherRestClientException):
     message = "HTTP response header is invalid"
 
 
-class InvalidContentType(ClientRestClientException):
-    message = "Invalid content type provided"
-
-
 class UnexpectedContentType(OtherRestClientException):
     message = "Unexpected content type provided"
 
@@ -149,6 +169,10 @@ class UnexpectedResponseCode(OtherRestClientException):
     message = "Unexpected response code received"
 
 
+class InvalidConfiguration(TempestException):
+    message = "Invalid Configuration"
+
+
 class InvalidIdentityVersion(TempestException):
     message = "Invalid version %(identity_version)s of the identity service"
 
@@ -227,6 +251,11 @@ class SSHExecCommandFailed(TempestException):
                "stdout:\n%(stdout)s")
 
 
+class SSHClientProxyClientLoop(TempestException):
+    message = ("SSH client proxy client has same host: %(host)s, port: "
+               "%(port)s and username: %(username)s as parent")
+
+
 class UnknownServiceClient(TempestException):
     message = "Service clients named %(services)s are not known"
 
@@ -239,3 +268,29 @@ class ServiceClientRegistrationException(TempestException):
 
 class PluginRegistrationException(TempestException):
     message = "Error registering plugin %(name)s: %(detailed_error)s"
+
+
+class VolumeBackupException(TempestException):
+    message = "Volume backup %(backup_id)s failed and is in ERROR status"
+
+
+class DeleteErrorException(TempestException):
+    message = ("Resource %(resource_id)s failed to delete "
+               "and is in ERROR status")
+
+
+class InvalidTestResource(TempestException):
+    message = "%(name)s is not a valid %(type)s, or the name is ambiguous"
+
+
+class InvalidParam(TempestException):
+    message = ("Invalid Parameter passed: %(invalid_param)s")
+
+
+class ConsistencyGroupException(TempestException):
+    message = "Consistency group %(cg_id)s failed and is in ERROR status"
+
+
+class ConsistencyGroupSnapshotException(TempestException):
+    message = ("Consistency group snapshot %(cgsnapshot_id)s failed and is "
+               "in ERROR status")
